==> haskell-x509-1.6.5-11-i686.pkg.tar.xz: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509
version: 1.6.5
id: x509-1.6.5-K5SLEQoLsUh3u9UsbQvMMB
key: x509-1.6.5-K5SLEQoLsUh3u9UsbQvMMB
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X509 reader and writer
description:
    X509 reader and writer
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509
hidden-modules: Data.X509.Internal Data.X509.CertificateChain
                Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
                Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
                Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
                Data.X509.Signed
abi: bb6969694615fc5eb8d51ae148961079
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/x509-1.6.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/x509-1.6.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/x509-1.6.5
hs-libraries: HSx509-1.6.5-K5SLEQoLsUh3u9UsbQvMMB
depends:
    asn1-encoding-0.9.5-fiNDlfe7eW4doDPmKz5l
    asn1-parse-0.9.4-5nVTJo02ohVIu2Ge47dEkn
    asn1-types-0.3.2-LxhcJbRPF00K2icDyHXu1r base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1
    cryptonite-0.22-JqiMjnb5zSBCoWgTNo13Ue
    hourglass-0.2.10-I8h0J4RSF89FN6CuD9x2Xx
    memory-0.14.3-7kBqUNxMvfU5uu32Wj2xqc
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM pem-0.2.2-qPMQP6sZm3HgQEmiBojNt
haddock-interfaces: /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html: /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-1.6.5-13-i686.pkg.tar.xz: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509
version: 1.6.5
id: x509-1.6.5-9laM1ngk9s070ouI9TLAmW
key: x509-1.6.5-9laM1ngk9s070ouI9TLAmW
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X509 reader and writer
description:
    X509 reader and writer
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509
hidden-modules: Data.X509.Internal Data.X509.CertificateChain
                Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
                Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
                Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
                Data.X509.Signed
abi: 507d7ce0cb9393b5d796657aeeaa408f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/x509-1.6.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/x509-1.6.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/x509-1.6.5
hs-libraries: HSx509-1.6.5-9laM1ngk9s070ouI9TLAmW
depends:
    asn1-encoding-0.9.5-A9izlTz6Ew2J4LAr7eelRX
    asn1-parse-0.9.4-L5R4UR6GVNoF5dX9YlNsKI
    asn1-types-0.3.2-6x3pk8jPDOL1GdLO9ZccNW base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1
    cryptonite-0.22-DUE2wxQoCnxGJxqhoLxB9Z
    hourglass-0.2.10-I8h0J4RSF89FN6CuD9x2Xx
    memory-0.14.5-8bv3NC3SoYTKu3JUzoaHbd
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM pem-0.2.2-qPMQP6sZm3HgQEmiBojNt
haddock-interfaces: /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html: /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
